
//*******************************************************************************************
//-This file is simple demonstration application for receiving data from BBMagic BUTTON sensor
//-You can run it on Raspberry Pi zero W or Raspberry Pi 3 with Bluetooth Low Energy
//-to see more visit: www.bbmagic.net
//-Copyright 2018 BBMagic Project ; see: _BBM_GNU_GPL_COPYING.txt
//*******************************************************************************************
//-Ten plik jest prost aplikacj demonstracyjn odbierajc dane z sensora BBMagic BUTTON
//-do uruchomienia na Raspberry Pi zero W lub Raspberry Pi 3 z Bluetooth Low Energy
//-aby dowiedzie si wicej zobacz: www.bbmagic.net
//-Copyright 2018 BBMagic Project ; zobacz: _BBM_GNU_GPL_COPYING.txt
//*******************************************************************************************


#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>
#include <time.h>
#include "bbmagic_lib.h"


#define TIME_BUF_SIZE   50

    int check_duplicate_msg(unsigned char *, unsigned char *) ;


//*******************************************************************************************
//-START APP
//*******************************************************************************************
int main(void)
{
    unsigned char bbm_buf[BBLIB_FRAME_SIZE], last_sig[4] ={0,0,0,0} ;
    int i, data_length ;

    time_t timestamp ;
    struct tm *loctime ;
    char time_buffer[TIME_BUF_SIZE] ;

    printf("\e[1;1H\e[2J") ;    //-clear terminal screen
    printf("\n==================================================================\n") ;
    printf("\n *** BBMagic BUTTON SCREENSHOT *** from www.bbmagic.net\n") ;
    printf(" 1.install scrot: 'sudo apt-get install scrot'\n") ;
    printf(" 2.run app sudo ./bbmagic_button_screenshot\n") ;
    printf(" 2.push button on BBMagic BUTTON module to take screenshot\n") ;
    printf(" hit 'ctrl+C' to stop bbmagic_button_screenshot app\n") ;
    printf("\n==================================================================\n") ;

    i = bbm_bt_lib_version() ;
    printf("bbm_lib_version: %0.4X - ",i) ;
    if(i == 0x0102) printf("ok\n") ;
    else
    {
        printf("nok - stop\n\n") ;
        exit(1) ;
    }

    i = bbm_bt_open(0) ;
    if(i) exit(2) ;

    printf("\n BBMagic BUTTON single click - take screenshot\n") ;
    printf(" BBMagic BUTTON holding - close app\n") ;
    printf(" keyboard 'ctrl+c' - close app\n") ;
    do
    {
        data_length = bbm_bt_read(bbm_buf) ;
        if(data_length > 0)
        {
            switch(bbm_buf[BBMAGIC_DEVICE_TYPE])
            {
                case BBMAGIC_M_BUTTON:

                    if(check_duplicate_msg(bbm_buf, last_sig) != 0) break ;

                    if(bbm_buf[BBM_BUTTON_BUTTON_FUNCTION] == BBM_BUTTON_FN_SINGLE_CLICK)
                    {
                        timestamp = time(NULL) ;            //-Get the current time
                        loctime = localtime(&timestamp) ;   //-Convert it to local time representation
                        strftime (time_buffer, TIME_BUF_SIZE, "%X", loctime) ; //-time string for filename

                        printf("\n **** %s taking screenshot\n", time_buffer) ;
                        printf("\n BBMagic BUTTON single click - take screenshot\n") ;
                        printf(" BBMagic BUTTON holding - close app\n") ;
                        printf(" keyboard 'ctrl+c' - close app\n") ;

                        system("scrot") ;
                    }
                    
                    if(bbm_buf[BBM_BUTTON_BUTTON_FUNCTION] == BBM_BUTTON_FN_HOLDING)
                    {
                        bbm_bt_close() ;
                        printf("\n You are holding the button so, see you next time. BYE !!\n\n") ;
                        exit(0) ;
                    }
                break ;

                default:
                    //printf("\n ********") ;
                break ;
            } ;
        }
        usleep(100) ;
    }while(data_length != -1) ;

    bbm_bt_close() ;

    exit(0) ;
}

//----------------------------------------------------------------------------------------------------
//-compares four bytes random number from BBMagic message bbm_buf[] and buffer last_sig[]
//-returns:
// 0 - numbers are different
// 1 - numbers are the same
//----------------------------------------------------------------------------------------------------
int check_duplicate_msg(unsigned char *bbm_buf, unsigned char *last_sig)
{
    int i, result =1 ;
    for(i =0; i<4; i++)
    {
        if(bbm_buf[BBM_BUTTON_SIGN_0+i] != last_sig[i])
        {
            result =0 ;
            last_sig[i] = bbm_buf[BBM_BUTTON_SIGN_0+i] ;
        }
    }
    return result ;
}


